@@ -171,6 +171,10 @@ class Detects(ServiceClass):
                                                 ),
                                           passed_keywords=kwargs
                                           )
+        if body.get("comment", None):
+            if not body.get("show_in_ui", None) and not body.get("status", None):
+                # Issue 563
+                body["show_in_ui"] = True
 
         return process_service_request(
             calling_object=self,
