@@ -1,4 +1,4 @@
-"""Falcon Machine Learning Exclusions API Interface Class
+"""Falcon Machine Learning Exclusions API Interface Class.
 
  _______                        __ _______ __        __ __
 |   _   .----.-----.--.--.--.--|  |   _   |  |_.----|__|  |--.-----.
@@ -42,7 +42,7 @@ from ._endpoint._ml_exclusions import _ml_exclusions_endpoints as Endpoints
 
 
 class MLExclusions(ServiceClass):
-    """The only requirement to instantiate an instance of this class is one of the following:
+    """The only requirement to instantiate an instance of this class is one of the following.
 
     - a valid client_id and client_secret provided as keywords.
     - a credential dictionary with client_id and client_secret containing valid API credentials
@@ -53,9 +53,10 @@ class MLExclusions(ServiceClass):
     - a previously-authenticated instance of the authentication service class (oauth2.py)
     - a valid token provided by the authentication service class (OAuth2.token())
     """
+
     @force_default(defaults=["parameters"], default_types=["dict"])
     def get_exclusions(self: object, *args, parameters: dict = None, **kwargs) -> dict:
-        """Get a set of ML Exclusions by specifying their IDs
+        """Get a set of ML Exclusions by specifying their IDs.
 
         Keyword arguments:
         ids -- List of exclusion IDs to retrieve. String or list of strings.
@@ -81,7 +82,7 @@ class MLExclusions(ServiceClass):
 
     @force_default(defaults=["parameters"], default_types=["dict"])
     def create_exclusions(self: object, body: dict = None, **kwargs) -> dict:
-        """Create the ML exclusions
+        """Create the ML exclusions.
 
         Keyword arguments:
         body -- full body payload, not required when using other keywords.
@@ -109,7 +110,6 @@ class MLExclusions(ServiceClass):
         Swagger URL
         https://assets.falcon.crowdstrike.com/support/api/swagger.html#/ml-exclusions/createMLExclusionsV1
         """
-
         if not body:
             body = exclusion_payload(passed_keywords=kwargs)
         if kwargs.get("excluded_from", None):
@@ -151,7 +151,7 @@ class MLExclusions(ServiceClass):
 
     @force_default(defaults=["parameters"], default_types=["dict"])
     def update_exclusions(self: object, body: dict = None, **kwargs) -> dict:
-        """Update the ML Exclusions
+        """Update the ML Exclusions.
 
         Keyword arguments:
         body -- full body payload, not required when using other keywords.
