@@ -38,6 +38,7 @@ For more information, please refer to <https://unlicense.org>
 import time
 from ._util import perform_request, generate_b64cred, confirm_base_region
 from ._util import confirm_base_url, generate_error_result
+from ._token_fail_reason import TokenFailReason
 from ._endpoint._oauth2 import _oauth2_endpoints as Endpoints
 
 
@@ -58,7 +59,7 @@ class OAuth2:
     def __init__(self: object, base_url: str = "https://api.crowdstrike.com",
                  ssl_verify: bool = True, proxy: dict = None, timeout: float or tuple = None,
                  creds: dict = None, client_id: str = None, client_secret: str = None,
-                 user_agent: str = None, member_cid: str = None):
+                 user_agent: str = None, member_cid: str = None, renew_window: int = 120):
         """Class constructor.
 
         Initializes the base class by ingesting credentials,
@@ -66,15 +67,18 @@ class OAuth2:
         for the base URL, SSL verification, and timeouts.
 
         Keyword arguments:
-        base_url -- CrowdStrike API URL to use for requests. [Default: US-1]
-        ssl_verify -- Boolean specifying if SSL verification should be used. [Default: True]
-        proxy -- Dictionary of proxies to be used for requests.
-        timeout -- Float or tuple specifying timeouts to use for requests.
-        creds -- Dictionary containing CrowdStrike API credentials.
-                 Mutually exclusive to client_id / client_secret.
-        client_id -- Client ID for the CrowdStrike API. Mutually exclusive to creds.
-        client_secret -- Client Secret for the CrowdStrike API. Mutually exclusive to creds.
-        member_cid -- Child CID to connec to. Mutually exclusive to creds.
+        base_url: CrowdStrike API URL to use for requests. [Default: US-1]
+        ssl_verify: Boolean specifying if SSL verification should be used. [Default: True]
+        proxy: Dictionary of proxies to be used for requests.
+        timeout: Float or tuple specifying timeouts to use for requests.
+        creds: Dictionary containing CrowdStrike API credentials.
+               Mutually exclusive to client_id / client_secret.
+        client_id: Client ID for the CrowdStrike API. Mutually exclusive to creds.
+        client_secret: Client Secret for the CrowdStrike API. Mutually exclusive to creds.
+        member_cid: Child CID to connect to. Mutually exclusive to creds.
+        renew_window: Amount of time (in seconds) between now and the token expiration before
+                      a refresh of the token is performed. Default: 120, Max: 1200
+                      Values over 1200 will be reset to the maximum.
 
         This method only supports keywords to specify arguments.
         """
@@ -97,7 +101,8 @@ class OAuth2:
         self.proxy = proxy
         self.user_agent = user_agent
         self.token_expiration = 0
-        self.token_renew_window = 20
+        # Maximum renewal window is 20 minutes, Minimum is 2 minutes
+        self.token_renew_window = max(min(renew_window, 1200), 120)
         self.token_time = time.time()
         self.token_value = False
         self.token_expired = lambda: bool(
@@ -150,11 +155,11 @@ class OAuth2:
                             self.token_fail_reason = returned["body"]["errors"][0]["message"]
             else:
                 returned = generate_error_result("Unexpected API response received", 403)
-                self.token_fail_reason = "Unexpected API response received"
+                self.token_fail_reason = TokenFailReason["UNEXPECTED"].value
                 self.token_status = 403
         else:
             returned = generate_error_result("Invalid credentials specified", 403)
-            self.token_fail_reason = "Invalid credentials specified"
+            self.token_fail_reason = TokenFailReason["INVALID"].value
             self.token_status = 403
 
         return returned
@@ -163,7 +168,7 @@ class OAuth2:
         """Revoke the specified authorization token.
 
         Keyword arguments:
-        token -- Token string to be revoked.
+        token: Token string to be revoked.
 
         When not specified as a keyword, token is assumed as the only accepted argument.
 
